@@ -43,19 +43,23 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include "ferret.h"
+#include "FerMem.h"
 
-void copy_c_string_(in_ptr, out_ptr)
-     char** out_ptr;
-     char** in_ptr;
+void FORTRAN(copy_c_string)(char **in_ptr, char **out_ptr)
 {
-   if ( *out_ptr != NULL )
-      free(*out_ptr);
+   if ( (*out_ptr != NULL) && (*out_ptr != STRING_MISSING_VALUE) )
+      FerMem_Free(*out_ptr, __FILE__, __LINE__);
    if ( *in_ptr == NULL ) {
      *out_ptr = NULL;
      return;
    }
+   if ( *in_ptr == STRING_MISSING_VALUE ) {
+      *out_ptr = STRING_MISSING_VALUE;
+      return;
+   }
 
-   *out_ptr = (char *) malloc(sizeof(char) * (strlen(*in_ptr) + 1));
+   *out_ptr = (char *) FerMem_Malloc(sizeof(char) * (strlen(*in_ptr) + 1), __FILE__, __LINE__);
    if ( *out_ptr == NULL )
       abort();
 
