@@ -135,6 +135,8 @@
 *                    definition of macro DFTYPE in ferret.h. ppl_memory remains float.
 * *kms*  2/16      - only catch/handle crash signals and exit gracefully if NDEBUG is defined;
 *                    if debug build, let it crash
+* *sh*  2/17       - removed global "memory" -- now 1 malloc per Ferret var
+* *acm* 5/17       - restore -memsize switch to make the initial SET MEMORY setting
 */
 
 #include <unistd.h>
@@ -143,27 +145,30 @@
 #include <string.h>
 #include <signal.h>
 #include "ferret.h"
+#include "FerMem.h"
 #include "ferret_shared_buffer.h"
+#include "pplmem.h"
+#include "xgks.h"
+
+/* Instantiate the globals in ferret_shared_buffer */
+smPtr sBuffer;
+float *ppl_memory;
 
-void gui_run(int *, char **);
-int gui_init();
 int its_script;
 char script_args[2048];
 int arg_pos;
 
-DFTYPE **gui_get_memory();
-static void command_line_run(DFTYPE **memory);
+static void command_line_run();
 
-void help_text()
+static void help_text(void)
 {
   printf(
-	 "Usage:  ferret [-memsize Mflts] [-batch [outfile]] [-server] [-secure] [-gif] [-gui] [-unmapped] [-help] [-nojnl] [-noverify] [-script [args]]\n"
+	 "Usage:  ferret [-memsize Mflts] [-batch [outfile]] [-server] [-secure] [-gif] [-unmapped] [-help] [-nojnl] [-noverify] [-script [args]]\n"
          "   -memsize:  specify the memory cache size (default 25.6) in mega (10^6) flts where a flt\n"
-         "              is 8 bytes in double-precision Ferret, 4 bytes in single-precision Ferret\n"
+         "              is 8 bytes in double-precision Ferret\n"
          "   -batch:  output directly to metafile \"outfile\" w/out X windows\n"
          "   -unmapped:  use invisible output windows (superceded by -batch)\n"
          "   -gif:  output to GIF file w/o X windows only w/ FRAME command\n"
-         "   -gui:  to start Ferret in point and click mode (not available on all platforms)\n"
          "   -secure:  run securely -- don't allow system commands\n"
          "   -server:  run in server mode -- don't stop on message commands\n"
          "   -help:  obtain this listing\n"
@@ -189,40 +194,24 @@ static void fer_signal_handler(int signal_num)
 }
 #endif
 
-/*
- * Eliminated _NO_PROTO ifdef (are there still non-ANSI C compilers around?)
- * JS
- */
 
-static int ttout_lun=TTOUT_LUN,
-  max_mem_blks=PMAX_MEM_BLKS,
-  mem_blk_size,
-  old_mem_blk_size,
-  pmemsize;
-
-/* make mem_size the appropriate type for malloc (size_t usually unsigned long) */
-static size_t mem_size = PMEM_BLK_SIZE * PMAX_MEM_BLKS;
+static int ttout_lun=TTOUT_LUN;
 
 
-main (int oargc, char *oargv[])
+int main(int oargc, char *oargv[])
 {
   int status;
-  smPtr sBuffer;
-  DFTYPE **memory = gui_get_memory(); 
   int argc = oargc;
   char **argv = oargv;
 
   int i=1;
   int j=1;
-  double rmem_size;
-  int using_gui = 0;
+  double rmem_size = 0;
   int pplmem_size;
 
-  int gui_enabled = gui_init();
   int journalfile = 1;
   int verify_flag = 1;
   int len_str;
-  int uvar_dset;
   int bat_mode;
 
   its_script = 0;
@@ -247,7 +236,8 @@ main (int oargc, char *oargv[])
 #endif
 
   /* decode the command line options: "-memsize", and "-unmapped" */
-  rmem_size = (double)mem_size/1.E6;
+  // pre-2017 code:   rmem_size = (double)mem_size/1.E6;
+  /* 5/17     pass rmem_size as is to init_memory, convert it there*/ 
   while (i<argc) {
     if (strcmp(argv[i],"-version")==0){
       FORTRAN(version_only)();
@@ -256,7 +246,7 @@ main (int oargc, char *oargv[])
       if (++i==argc) help_text();
       if ( sscanf(argv[i++],"%lf",&rmem_size) != 1 ) help_text();
       if ( rmem_size <= 0.0 ) help_text();
-      mem_size = (size_t)(rmem_size * 1.E6);
+      // pre-2017 code:    mem_size = (size_t)(rmem_size * 1.E6);
     } else if (strcmp(argv[i],"-unmapped")==0) {
       WindowMapping(0);  /* new routine added to xopws.c */
       i++;    /* advance to next argument */
@@ -288,14 +278,6 @@ main (int oargc, char *oargv[])
       verify_flag = 0;    
 	  ++i;
       
-    } else if (strcmp(argv[i],"-gui")==0) {
-      i++;
-      if (gui_enabled){
-	using_gui = 1;  /* new routine added to xopws.c */
-      } else {
-	fprintf(stderr,
-		"Warning: the -gui flag has no effect on this platform\n");
-      }
     /* -script mode implies -server and -nojnl */
     } else if (strcmp(argv[i],"-script")==0)  {
 
@@ -368,33 +350,38 @@ main (int oargc, char *oargv[])
   }
 
   /* initial allocation of memory space */
-  mem_blk_size =  mem_size / max_mem_blks;
-  j = (int)(mem_size - ((size_t)mem_blk_size * (size_t) max_mem_blks));
-  if ( (mem_blk_size <= 0) || (j < 0) || (j >= max_mem_blks) ) { 
-    printf("Internal overflow expressing %#.1f Mwords as words (%lu) \n",rmem_size,(unsigned long)mem_size);
-    printf("Unable to allocate the requested %#.1f Mwords of memory.\n",rmem_size);
-    exit(0);
-  }
-  /* Reset mem_size to exactly the size Ferret thinks it is being handed */
-  mem_size = (size_t)mem_blk_size * (size_t)max_mem_blks;
-  *memory = (DFTYPE *) malloc(mem_size*sizeof(DFTYPE));
 
-  if ( *memory == NULL ) {
-    printf("Unable to allocate the requested %#.1f Mwords of memory.\n",(double)mem_size/1.E6);
-    exit(0);
-  }
+  /* ***** COMMENTED OUT 2/2017 with removal of block-oriented memory */
+
+  //  mem_blk_size =  mem_size / max_mem_blks;
+  //  j = (int)(mem_size - ((size_t)mem_blk_size * (size_t) max_mem_blks));
+  //  if ( (mem_blk_size <= 0) || (j < 0) || (j >= max_mem_blks) ) { 
+  //    printf("Internal overflow expressing %#.1f Mwords as words (%lu) \n",rmem_size,(unsigned long)mem_size);
+  //    printf("Unable to allocate the requested %#.1f Mwords of memory.\n",rmem_size);
+  //    exit(0);
+  //  }
+  //  /* Reset mem_size to exactly the size Ferret thinks it is being handed */
+  //  mem_size = (size_t)mem_blk_size * (size_t)max_mem_blks;
+  //  *memory = (DFTYPE *) malloc(mem_size*sizeof(DFTYPE));
+  //
+  //  if ( *memory == NULL ) {
+  //    printf("Unable to allocate the requested %#.1f Mwords of memory.\n",(double)mem_size/1.E6);
+  //    exit(0);
+  //  }
+
+  /* ***** END OF COMMENTED OUT MEMORY CODE */
  
   /* initial allocation of PPLUS memory size pointer*/
   pplmem_size = (int)(0.5* 1.E6);  
   FORTRAN(save_ppl_memory_size)( &pplmem_size ); 
-  ppl_memory = (float *) malloc(sizeof(float) * pplmem_size );
+  ppl_memory = (float *) FerMem_Malloc(sizeof(float) * pplmem_size, __FILE__, __LINE__);
 
   if ( ppl_memory == NULL ) {
     printf("Unable to allocate the initial %d words of PLOT memory.\n",pplmem_size);
-    exit(0);
+    exit(1);
   }
   /* initialize stuff: keyboard, todays date, grids, GFDL terms, PPL brain */
-  FORTRAN(initialize)();
+  FORTRAN(initialize_ferret)();
 
   /*  prepare appropriate console input state and open the output journal file */
 
@@ -409,13 +396,9 @@ main (int oargc, char *oargv[])
   }
 
   /* initialize size and shape of memory and linked lists */
-  FORTRAN(init_memory)( &mem_blk_size, &max_mem_blks );
+  FORTRAN(init_memory)(&rmem_size);
 
-  if ( using_gui ) {
-    gui_run(&argc, argv);
-  } else {
-    command_line_run(memory);
-  }
+  command_line_run();
   /* 
    *kob* 5/97 - need to close f90 files and flush buffers.....
    */
@@ -426,17 +409,15 @@ main (int oargc, char *oargv[])
 #ifdef __CYGWIN__
   for_rtl_finish_(&argc, argv);
 #endif
+  return 0;
 }
 
-  static void command_line_run(DFTYPE **memory){
-
+static void command_line_run()
+{
   FILE *fp = 0;
   char init_command[2176], script_file[2048], *home = getenv("HOME");
   int ipath = 0;
-  int len_str = 0;
   int script_resetmem = 0;
-  size_t blk_size;
-  double rmem_size;
 
   /* turn on ^C interrupts  */
   /* 10/97 *kob* add check for gui now that there is only one main program */
@@ -465,6 +446,7 @@ main (int oargc, char *oargv[])
   
     if (its_script)
     {
+        /* assume Unix-style passing of Holerith strings - add size as int to end */
 	FORTRAN(get_scriptfile_name)(script_file, &ipath, 2048);
       if ( ipath ) {
 	  strcat( init_command, "; GO \"" ); 
@@ -477,14 +459,13 @@ main (int oargc, char *oargv[])
 	  strcat( init_command, " ");
       }
 	  if (arg_pos !=0) {
-	       len_str = strlen(init_command);
 		   strcat( init_command, script_args );
 	  }
 	  strcat( init_command, "; EXIT/PROGRAM");
     }
 
   /* allocate the shared buffer */
-  sBuffer = (sharedMem *)malloc(sizeof(sharedMem));
+  sBuffer = (sharedMem *)FerMem_Malloc(sizeof(sharedMem), __FILE__, __LINE__);
 
  
   /* run the initialization file
@@ -501,9 +482,9 @@ main (int oargc, char *oargv[])
 
 	if ( script_resetmem == 0 )
 	  {
-      ferret_dispatch_c( *memory, init_command, sBuffer );
+      ferret_dispatch_c( init_command, sBuffer );
 	  } else {
-	  ferret_dispatch_c( *memory, " ", sBuffer );
+	  ferret_dispatch_c( " ", sBuffer );
 	  script_resetmem = 0;
 	  }
 
@@ -517,48 +498,61 @@ main (int oargc, char *oargv[])
 
     /* ***** REALLOCATE MEMORY ***** */
     if (sBuffer->flags[FRTN_ACTION] == FACTN_MEM_RECONFIGURE) {
-      old_mem_blk_size = mem_blk_size;
-      mem_blk_size = sBuffer->flags[FRTN_IDATA1];
-      mem_size = (size_t)mem_blk_size * (size_t)max_mem_blks;
-      /* Make sure this has not overflowed */
-      blk_size = mem_size / (size_t) max_mem_blks;
-      if ( blk_size != (size_t)mem_blk_size ) {
-        rmem_size = (double)mem_blk_size * (double)max_mem_blks / 1.0E6;
-        printf("Internal overflow expressing %#.1f Mwords as words (%lu) \n",rmem_size,(unsigned long)mem_size);
-        printf("Unable to allocate the requested %#.1f Mwords of memory.\n",rmem_size);
-	mem_blk_size = old_mem_blk_size;
-	mem_size = (size_t)mem_blk_size * (size_t)max_mem_blks;
-	printf("Memory remaining at %#.1f Mwords.\n", (double)mem_size/1.E6);
-      }
-      else {
-        /*
-	  printf("memory reconfiguration requested: %lu\n",(unsigned long)mem_size);
-	  printf("new mem_blk_size = %d\n",mem_blk_size);
-        */
-        free( (void *) *memory );
-        *memory = (DFTYPE *) malloc(mem_size*sizeof(DFTYPE));
 
-        if ( *memory == NULL ) {
-          printf("Unable to allocate %#.1f Mwords of memory.\n", (double)mem_size/1.E6);
-          mem_blk_size = old_mem_blk_size;
-          mem_size = (size_t)mem_blk_size * (size_t)max_mem_blks;
-          *memory = (DFTYPE *) malloc(mem_size*sizeof(DFTYPE));
+      /* TAKE NO ACTION -- MEMORY NO LONGER ALLOCATED HERE */
+
+/* **** START OF PRE-2017 MEMORY MANAGEMENT CODE */
+//      old_mem_blk_size = mem_blk_size;
+//      mem_blk_size = sBuffer->flags[FRTN_IDATA1];
+//      mem_size = (size_t)mem_blk_size * (size_t)max_mem_blks;
+//      /* Make sure this has not overflowed */
+//      blk_size = mem_size / (size_t) max_mem_blks;
+//      if ( blk_size != (size_t)mem_blk_size ) {
+//        rmem_size = (double)mem_blk_size * (double)max_mem_blks / 1.0E6;
+//        printf("Internal overflow expressing %#.1f Mwords as words (%lu) \n",rmem_size,(unsigned long)mem_size);
+//        printf("Unable to allocate the requested %#.1f Mwords of memory.\n",rmem_size);
+//	mem_blk_size = old_mem_blk_size;
+//	mem_size = (size_t)mem_blk_size * (size_t)max_mem_blks;
+//	printf("Memory remaining at %#.1f Mwords.\n", (double)mem_size/1.E6);
+//      }
+//      else {
+//        /*
+//	  printf("memory reconfiguration requested: %lu\n",(unsigned long)mem_size);
+//	  printf("new mem_blk_size = %d\n",mem_blk_size);
+//        */
+//        free( (void *) *memory );
+//        *memory = (DFTYPE *) malloc(mem_size*sizeof(DFTYPE));
+//
+//        if ( *memory == NULL ) {
+//          printf("Unable to allocate %#.1f Mwords of memory.\n", (double)mem_size/1.E6);
+//          mem_blk_size = old_mem_blk_size;
+//          mem_size = (size_t)mem_blk_size * (size_t)max_mem_blks;
+//          *memory = (DFTYPE *) malloc(mem_size*sizeof(DFTYPE));
+//
+//          if ( *memory == NULL ) {
+//            printf("Unable to reallocate previous memory of %#.1f Mwords.\n",(double)(mem_size)/1.E6);
+//            exit(0);
+//          }
+//	  printf("Restoring previous memory of %#.1f Mwords.\n", (double)(mem_size)/1.E6);
+//        }
+//      }
+//      FORTRAN(init_memory)();
+//      script_resetmem = 1;
+/* **** END OF PRE-2017 MEMORY MANAGEMENT CODE */
 
-          if ( *memory == NULL ) {
-            printf("Unable to reallocate previous memory of %#.1f Mwords.\n",(double)(mem_size)/1.E6);
-            exit(0);
-          }
-	  printf("Restoring previous memory of %#.1f Mwords.\n", (double)(mem_size)/1.E6);
-        }
-      }
-      FORTRAN(init_memory)( &mem_blk_size, &max_mem_blks );
-      script_resetmem = 1;
     }
 
     /* ***** EXIT ***** */
     else if  (sBuffer->flags[FRTN_ACTION] == FACTN_EXIT ) {
       /*      printf("exit from FERRET requested\n"); */
-      FORTRAN(finalize)();
+      FORTRAN(finalize_ferret)();
+      if ( sBuffer != NULL )
+          FerMem_Free(sBuffer, __FILE__, __LINE__);
+      if ( ppl_memory != NULL )
+          FerMem_Free(ppl_memory, __FILE__, __LINE__);
+#ifdef MEMORYDEBUG
+      (void) ReportAnyMemoryLeaks();
+#endif
       exit(0);
     }
 
