@@ -54,28 +54,26 @@
  *       char *data;
  */
 
-static char brag[] = "$$Version: list-2.1 Copyright (C) 1992 Bradley C. Spatz";
-
 /* *acm   9/06 v600 - add stdlib.h wherever there is stdio.h for altix build*/ 
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include "ferret.h"
+#include "FerMem.h"
 #include "list.h"
 
-/*char *malloc();*/
 
-
-LIST *list_init(void)
+LIST *list_init(char *filename, int linenum)
 {
    LIST *list;
 
    /* Allocate, initialize, and return a new list. */
-   list = (LIST *) malloc(sizeof(LIST));
+   list = (LIST *) FerMem_Malloc(sizeof(LIST), filename, linenum);
    list->size = 0;
-   list->front = NULL;;
-   list->rear = NULL;;
-   list->curr = NULL;;
+   list->front = NULL;
+   list->rear = NULL;
+   list->curr = NULL;
    return(list);
 }
 
@@ -169,14 +167,14 @@ int list_size(LIST *list)
  * #endif
  */
 
-static LIST_ELEMENT *list_create_element(char *data, int bytes)
+static LIST_ELEMENT *list_create_element(char *data, int bytes, char *filename, int linenum)
 {
    LIST_ELEMENT *new;
 
    /* Allocate storage for the new node and its data.  Return NULL if
     * unable to allocate.
     */
-   new = (LIST_ELEMENT *) malloc(sizeof(LIST_ELEMENT));
+   new = (LIST_ELEMENT *) FerMem_Malloc(sizeof(LIST_ELEMENT), filename, linenum);
    if (new == NULL) {
       return(NULL);
    }
@@ -185,8 +183,9 @@ static LIST_ELEMENT *list_create_element(char *data, int bytes)
     * Then either copy the data or just the reference into the node.
     */
    if (bytes > 0) {
-      new->data = (char *) malloc(bytes);
+      new->data = (char *) FerMem_Malloc(bytes, filename, linenum);
       if (new->data == NULL) {
+         FerMem_Free(new, filename, linenum);
 	 return(NULL);
       }
       (void) memcpy(new->data, data, bytes);
@@ -199,12 +198,12 @@ static LIST_ELEMENT *list_create_element(char *data, int bytes)
 }
 
 
-char *list_insert_before(LIST *list, char *data, int bytes)
+char *list_insert_before(LIST *list, char *data, int bytes, char *filename, int linenum)
 {
    LIST_ELEMENT *new;
 
    /* Allocate storage for the new element and its data.*/
-   new = list_create_element(data, bytes);
+   new = list_create_element(data, bytes, filename, linenum);
    if (new == NULL)
       return(NULL);
 
@@ -240,12 +239,12 @@ char *list_insert_before(LIST *list, char *data, int bytes)
 }
 
 
-char *list_insert_after(LIST *list, char *data, int bytes)
+char *list_insert_after(LIST *list, char *data, int bytes, char *filename, int linenum)
 {
    LIST_ELEMENT *new;
 
    /* Allocate storage for the new element and its data.*/
-   new = list_create_element(data, bytes);
+   new = list_create_element(data, bytes, filename, linenum);
    if (new == NULL)
       return(NULL);
 
@@ -281,20 +280,20 @@ char *list_insert_after(LIST *list, char *data, int bytes)
 }
 
 
-static char *list_remove_single(LIST *list)
+static char *list_remove_single(LIST *list, char *filename, int linenum)
 {
    char *data;
 
    /* The list has one element.  Easy. */
    data = list->curr->data;
-   free(list->curr);
+   FerMem_Free(list->curr, filename, linenum);
    list->front = list->rear = list->curr = NULL;
    list->size--;
    return (data);
 }
 
 
-char *list_remove_front(LIST *list)
+char *list_remove_front(LIST *list, char *filename, int linenum)
 {
    LIST_ELEMENT *temp;
    char *data;
@@ -308,7 +307,7 @@ char *list_remove_front(LIST *list)
    }
    else if (list->front == list->rear) {
       /* List has only one element.  Easy. */
-      data = list_remove_single(list);
+      data = list_remove_single(list, filename, linenum);
    }
    else {
       /* List has more than one element.  Make sure to check if curr
@@ -320,7 +319,7 @@ char *list_remove_front(LIST *list)
       list->front = temp->next;
       if (list->curr == temp)
 	 list->curr = temp->next;
-      free(temp);
+      FerMem_Free(temp, filename, linenum);
       list->size--;
    }
 
@@ -328,7 +327,7 @@ char *list_remove_front(LIST *list)
 }
 
 
-char *list_remove_rear(LIST *list)
+char *list_remove_rear(LIST *list, char *filename, int linenum)
 {
    LIST_ELEMENT *temp;
    char *data;
@@ -342,7 +341,7 @@ char *list_remove_rear(LIST *list)
    }
    else if (list->front == list->rear) {
       /* List has only one element.  Easy. */
-      data = list_remove_single(list);
+      data = list_remove_single(list, filename, linenum);
    }
    else {
       /* List has more than one element.  Make sure to check if curr
@@ -354,7 +353,7 @@ char *list_remove_rear(LIST *list)
       list->rear = temp->prev;
       if (list->curr == temp)
 	 list->curr = temp->prev;
-      free(temp);
+      FerMem_Free(temp, filename, linenum);
       list->size--;
    }
 
@@ -362,7 +361,7 @@ char *list_remove_rear(LIST *list)
 }
 
 
-char *list_remove_curr(LIST *list)
+char *list_remove_curr(LIST *list, char *filename, int linenum)
 {
    LIST_ELEMENT *temp;
    char *data;
@@ -378,15 +377,15 @@ char *list_remove_curr(LIST *list)
    }
    else if (list->front == list->rear) {
       /* The list has one element.  Easy. */
-      data = list_remove_single(list);
+      data = list_remove_single(list, filename, linenum);
    }
    else if (list->curr == list->front) {
       /* Removing front element.  Easy. */
-      data = list_remove_front(list);
+      data = list_remove_front(list, filename, linenum);
    }
    else if (list->curr == list->rear) {
       /* Removing from the rear.  Easy.*/
-      data = list_remove_rear(list);
+      data = list_remove_rear(list, filename, linenum);
    }
    else {
       /* Otherwise.  Must be inside a 3-element or larger list. */
@@ -395,7 +394,7 @@ char *list_remove_curr(LIST *list)
       temp->next->prev = temp->prev;
       temp->prev->next = temp->next;
       list->curr = temp->next;
-      free(temp);
+      FerMem_Free(temp, filename, linenum);
       list->size--;
    }
 
@@ -459,7 +458,7 @@ int list_traverse(LIST *list, char *data, int (*func)(char *, char *), int opts)
 }
 
 
-void list_free(LIST *list, void (*dealloc)(char *))
+void list_free(LIST *list, void (*dealloc)(char *), char *filename, int linenum)
 {
    char *data;
 
@@ -470,13 +469,13 @@ void list_free(LIST *list, void (*dealloc)(char *))
     */
    list_mvfront(list);
    while (! list_empty(list)) {
-      data = list_remove_front(list);
+      data = list_remove_front(list, filename, linenum);
       /* Apply either no deallocation function to each node, our own, or
        * a user-supplied version.
        */
       if ( dealloc != LIST_NODEALLOC ) {
 	 if ( dealloc == LIST_DEALLOC ) {
-	    free(data);
+	    FerMem_Free(data, filename, linenum);
 	 }
 	 else {
 	    (*dealloc)(data);
@@ -484,5 +483,5 @@ void list_free(LIST *list, void (*dealloc)(char *))
       }
    }
 
-   free(list);
+   FerMem_Free(list, filename, linenum);
 }
