@@ -39,10 +39,10 @@
  */
  
 #include <stdlib.h>
+#include "ferret.h"
+#include "FerMem.h"
 
-void set_null_c_string_array_(fer_ptr, nstr)
-     char*** fer_ptr;
-     int* nstr;
+void FORTRAN(set_null_c_string_array)(char ***fer_ptr, int *nstr)
 {
    char** each_str_ptr;
    int i;
@@ -50,13 +50,9 @@ void set_null_c_string_array_(fer_ptr, nstr)
    each_str_ptr = *fer_ptr;   /* holds pointer to the first string */
 
    for (i=0; i<*nstr; i++) {
-      if ( *each_str_ptr != NULL )
-         free(*each_str_ptr);
-      *each_str_ptr = (char *) malloc(sizeof(char));
-      if ( *each_str_ptr == NULL )
-         abort();
-      **each_str_ptr = '\0';
-
+      if ( (*each_str_ptr != NULL) && (*each_str_ptr != STRING_MISSING_VALUE) )
+         FerMem_Free(*each_str_ptr, __FILE__, __LINE__);
+      *each_str_ptr = STRING_MISSING_VALUE;
       each_str_ptr += 8/sizeof(char**);
    }
 }
