@@ -93,30 +93,27 @@ typedef        unsigned char   char_type;
 /**************************************************************************/
 /* static char_type	*data; */
 static char_type	*data;
-static int		iwidth, iheight, image_offset;
+static int		iwidth, iheight;
 /**************************************************************************/
-typedef int (* ifunptr)();                              /* Pointer to function returning an int */
+typedef int (* ifunptr)(int,int);                              /* Pointer to function returning an int */
  
-int GetPixel( int, int );
-
-static Putword( int, FILE *);
-static cl_block ();   
-static cl_hash(register count_int);
-static writeerr();
-static char_init();
-static char_out( int );
-static flush_char();
-static output( code_int );
+static void GIFEncode( FILE *, int, int, int, int, int, int[], int[], int[], ifunptr );
+static int  GetPixel( int, int );
+static void Putword( int, FILE * );
+static void wcompress( int, FILE *, ifunptr );
+static void cl_block( void );   
+static void cl_hash( register count_int );
+static void writeerr( void );
+static void char_init( void );
+static void char_out( int );
+static void flush_char( void );
+static void output( code_int );
 
 
 
-void wGIF(fp, image,r,g,b)
-     FILE *fp;
-     XImage *image;
-     int r[],g[],b[];
+void wGIF(FILE *fp, XImage *image, int r[], int g[], int b[])
 {
-
-     int x,y;
+     int x;
 
 /* Set global variables needed for GetPixel routine */
 /* cast image-> data to unsigned character ptr. 6/12/96 *kob* */
@@ -156,7 +153,7 @@ static long CountDown;
 static int Pass = 0;
 static int Interlace;
  
-static BumpPixel() /* Bump the 'curx' and 'cury' to point to the next pixel */
+static void BumpPixel() /* Bump the 'curx' and 'cury' to point to the next pixel */
 {
     curx++;         /* Bump the current X position */
  
@@ -211,7 +208,7 @@ static BumpPixel() /* Bump the 'curx' and 'cury' to point to the next pixel */
 }
  
  
-GIFGetPixel( getpixel )                        /* Return the next pixel from the image */
+static int GIFGetPixel( getpixel )                        /* Return the next pixel from the image */
 ifunptr getpixel;
 {
         int r;
@@ -231,8 +228,8 @@ ifunptr getpixel;
  
  
  
-GIFEncode( fp, GWidth, GHeight, GInterlace, Background,
-           BitsPerPixel, Red, Green, Blue, GetPixel )
+static void GIFEncode( fp, GWidth, GHeight, GInterlace, Background,
+           BitsPerPixel, Red, Green, Blue, GetPixelFunc )
  
 FILE *fp;
 int GWidth;
@@ -241,7 +238,7 @@ int GInterlace;
 int Background;
 int BitsPerPixel;
 int Red[], Green[], Blue[];
-ifunptr GetPixel;
+ifunptr GetPixelFunc;
  
 {
         int B;
@@ -311,7 +308,7 @@ ifunptr GetPixel;
         fputc( InitCodeSize, fp );                      /* Write out the initial code size */
  
  /* renamed from compress because of conflict under x86-64_linux with  /usr/lib64/libz.a(compress.o) */
-        wcompress( InitCodeSize+1, fp, GetPixel );               /* Actually compress data */
+        wcompress( InitCodeSize+1, fp, GetPixelFunc );               /* Actually compress data */
  
  
  
@@ -323,7 +320,7 @@ ifunptr GetPixel;
  
  
  
-static Putword( w, fp )                                 /* Write out a word to the GIF file */
+static void Putword( w, fp )                                 /* Write out a word to the GIF file */
 int w;
 FILE *fp;
 {
@@ -376,7 +373,6 @@ static unsigned short codetab [HSIZE];
 #define CodeTabOf(i)    codetab[i]
  
 static code_int hsize = HSIZE;                 /* for dynamic table sizing */
-static count_int fsize;
  
 /*
  * To save much memory, we overlay the table used by compress() with those
@@ -392,7 +388,6 @@ static count_int fsize;
 #define de_stack               ((char_type *)&tab_suffixof((code_int)1<<BITS))
  
 static code_int free_ent = 0;                  /* first unused entry */
-static int exit_stat = 0;
  
 /*
  * block compression parameters -- after all codes are used up,
@@ -426,7 +421,7 @@ static FILE *g_outfile;
 static int ClearCode;
 static int EOFCode;
  
-wcompress( init_bits, outfile, ReadValue )
+static void wcompress( init_bits, outfile, ReadValue )
 int init_bits;
 FILE *outfile;
 ifunptr ReadValue;
@@ -555,7 +550,7 @@ unsigned long masks[] = { 0x0000, 0x0001, 0x0003, 0x0007, 0x000F,
  
  
  
-static output( code )
+static void output( code )
 code_int  code;
 {
     cur_accum &= masks[ cur_bits ];
@@ -617,7 +612,7 @@ code_int  code;
  
  
  
-static cl_block ()             /* table clear for block compress */
+static void cl_block (void)             /* table clear for block compress */
 {
  
         cl_hash ( (count_int) hsize );
@@ -629,7 +624,7 @@ static cl_block ()             /* table clear for block compress */
  
  
  
-static cl_hash(hsize)                                                                   /* reset code table */
+static void cl_hash(hsize)                                                                   /* reset code table */
 register count_int hsize;
 {
  
@@ -666,7 +661,7 @@ register count_int hsize;
  
  
  
-static writeerr()
+static void writeerr()
 {
         printf( "error writing output file\n" );
         exit(1);
@@ -682,7 +677,7 @@ static int a_count;                     /* Number of characters so far in this '
  
  
  
-static char_init()                      /* Set up the 'byte output' routine */
+static void char_init()                      /* Set up the 'byte output' routine */
 {
         a_count = 0;
 }
@@ -693,7 +688,7 @@ static char accum[ 256 ];       /* Define the storage for the packet accumulator
  
  
  
-static char_out( c )                    /* Add character to end, if 254 characters, flush */
+static void char_out( c )                    /* Add character to end, if 254 characters, flush */
 int c;
 {
         accum[ a_count++ ] = c;
@@ -703,7 +698,7 @@ int c;
  
  
  
-static flush_char() /* Flush the packet to disk, and reset the accumulator */
+static void flush_char() /* Flush the packet to disk, and reset the accumulator */
 {
         if( a_count > 0 )
                 {
@@ -714,7 +709,7 @@ static flush_char() /* Flush the packet to disk, and reset the accumulator */
 }
  
 /*************************************************************************/
-int GetPixel( x, y )
+static int GetPixel( x, y )
 int x, y;
 {
       return data[ y*iwidth + x];
