@@ -55,23 +55,18 @@
 #include <stdlib.h>
 #include <netcdf.h>
 
-#include "ferretmacros.h"
+#include "fmtprotos.h"
 #include "list.h"
 #include "NCF_Util.h"
+#include "FerMem.h"
 
 
 /* prototype */
-void tm_scale_buffer(DFTYPE *dat, double *dbuff,
-			   DFTYPE *offset, DFTYPE *scale, DFTYPE *bad,
-			   int ntotal);
-
-void FORTRAN(cd_read_scale) (int *cdfid, int *varid, int *dims, 
-			   DFTYPE *offset, DFTYPE *scale, DFTYPE* bad,
-			   int *tmp_start, int *tmp_count, 
-			   int *tmp_stride, int *tmp_imap,
-			   void *dat, int *permuted, int *strided, int *already_scaled,
-			   int *cdfstat, int *status)
+static void tm_scale_buffer(DFTYPE *dat, double *dbuff, DFTYPE *offset, DFTYPE *scale, DFTYPE *bad, int ntotal);
 
+void FORTRAN(cd_read_scale)(int *cdfid, int *varid, int *dims, DFTYPE *offset, DFTYPE *scale, DFTYPE* bad,
+                            int *tmp_start, int *tmp_count, int *tmp_stride, int *tmp_imap,
+                            void *dat, int *permuted, int *strided, int *already_scaled, int *cdfstat, int *status)
 {
 
   /* convert FORTRAN-index-ordered, FORTRAN-1-referenced ids, count,
@@ -84,12 +79,10 @@ void FORTRAN(cd_read_scale) (int *cdfid, int *varid, int *dims,
   size_t start[NFERDIMSP1], count[NFERDIMSP1];
   ptrdiff_t stride[NFERDIMSP1], imap[NFERDIMSP1];
 
-  int tmp, i, maxstrlen, ndimsp, *dimids;
-  size_t bufsiz;
+  int tmp, i;
   int ndim = *dims - 1; /* C referenced to zero */
   int vid = *varid;
   nc_type vtyp;
-  int n_sections;
   int ntotal;
   int scale_it;
   double *data_double;
@@ -152,7 +145,7 @@ void FORTRAN(cd_read_scale) (int *cdfid, int *varid, int *dims,
 	   in variable dat
     */
 
-      data_double = (double *) malloc(ntotal * sizeof(double));
+      data_double = (double *) FerMem_Malloc(ntotal * sizeof(double), __FILE__, __LINE__);
       if ( data_double == NULL )
           abort();
 
@@ -177,7 +170,7 @@ void FORTRAN(cd_read_scale) (int *cdfid, int *varid, int *dims,
          scale, bad, ntotal);
 	  *already_scaled = 1;
 
-	  free(data_double);
+	  FerMem_Free(data_double, __FILE__, __LINE__);
                   
   }
    
@@ -220,10 +213,7 @@ void FORTRAN(cd_read_scale) (int *cdfid, int *varid, int *dims,
 }
 
 /*  */
-void tm_scale_buffer(DFTYPE *dat, double *dbuff,
-                     DFTYPE *offset, DFTYPE *scale, DFTYPE *bad,
-                     int ntotal)
-
+static void tm_scale_buffer(DFTYPE *dat, double *dbuff, DFTYPE *offset, DFTYPE *scale, DFTYPE *bad, int ntotal)
 {
         int j;
         double dbad;
